@@ -1,21 +1,21 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "forge" "0.6.3"
+(define-package "forge" "20251113.2133"
   "Access Git forges from Magit."
   '((emacs         "29.1")
     (compat        "30.1")
-    (closql        "2.4")
+    (closql        "2.3")
     (cond-let      "0.2")
     (emacsql       "4.3")
     (ghub          "5.0")
     (llama         "1.0")
-    (magit         "4.5")
+    (magit         "4.4")
     (markdown-mode "2.7")
     (seq           "2.24")
-    (transient     "0.12")
+    (transient     "0.10")
     (yaml          "1.2"))
   :url "https://github.com/magit/forge"
-  :commit "315e8e9a2b45d050ca7fc717595cc698e175b140"
-  :revdesc "v0.6.3-0-g315e8e9a2b45"
+  :commit "37b4b2bf8f946db588b51fbaf5f27662739fdfe8"
+  :revdesc "37b4b2bf8f94"
   :keywords '("git" "tools" "vc")
   :authors '(("Jonas Bernoulli" . "emacs.forge@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.forge@jonas.bernoulli.dev")))
